"""
Command for scheduling or running the task for notifying sponsors of
expiring roles.
"""

import logging
import logging.config

from django.conf import settings
from django.core.management.base import BaseCommand, CommandParser
from django_q.tasks import schedule

from greg.tasks import notify_sponsors_roles_ending

logging.config.dictConfig(settings.LOGGING)
logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = __doc__

    def add_arguments(self, parser: CommandParser) -> None:
        parser.add_argument(
            "--schedule",
            default=False,
            action="store_true",
            help="Add a scheduled task for running the role end notifier",
        )
        parser.add_argument(
            "--run-once",
            default=False,
            action="store_true",
            help="Run the import once",
        )

    def handle(self, *args, **options):
        if options["schedule"]:
            self.schedule()
            return

        if options["run_once"]:
            notify_sponsors_roles_ending()
            return

        logger.info("Nothing done")

    def schedule(self, *args, **options):
        logger.info("Scheduling role end notifier task...")
        schedule(
            func="greg.tasks.notify_sponsors_roles_ending",
            schedule_type=settings.NOTIFIER_SCHEDULE_TYPE,
        )
        logger.info("Role end notifier task scheduled.")
