import logging

from django.template.context import Context
from django_q.tasks import async_task

from gregui.mailutils.protocol import prepare_arguments
from gregui.models import EmailTemplate

logger = logging.getLogger(__name__)


class RolesEnding:
    def __init__(self):
        pass

    def queue_mail(self, mail_to: str, num_roles: int) -> str:
        logger.info(
            "Queuing a role end notification email to %s about %d roles",
            mail_to,
            num_roles,
        )
        arguments = prepare_arguments(
            template=EmailTemplate.objects.get(
                template_key=EmailTemplate.EmailType.ROLE_END_REMINDER
            ),
            context=Context({"num_roles": num_roles}),
            mail_to=mail_to,
        )
        return async_task("django.core.mail.send_mail", **arguments)
